# Generated by Django 2.1.2 on 2019-05-07 15:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('autopost', '0006_auto_20190201_2356'),
    ]

    operations = [
        migrations.AddField(
            model_name='article',
            name='slug',
            field=models.SlugField(blank=True, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='article',
            name='title',
            field=models.CharField(db_index=True, max_length=255, verbose_name='标题'),
        ),
        migrations.AlterField(
            model_name='category',
            name='status',
            field=models.IntegerField(choices=[(0, '隐藏'), (2, '主菜单'), (1, '显示')], default=1, verbose_name='状态'),
        ),
    ]
